==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/practicedSystem/practicedIntervention/PracticedInterventionImportDto.java <==
package fr.inra.agrosyst.services.pz0import.practicedSystem.practicedIntervention;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: PracticedInterventionImportDto.java 4775 2015-02-10 15:13:34Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/practicedSystem/practicedIntervention/PracticedInterventionImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.services.practiced.PracticedInterventionDto;

/**
 * Created by davidcosse on 05/02/15.
 */
public class PracticedInterventionImportDto extends PracticedInterventionDto {

    protected String id;

    protected String practicedCropCyclePhaseId;

    protected String practicedCropCycleConnectionId;

    protected String typeName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPracticedCropCyclePhaseId() {
        return practicedCropCyclePhaseId;
    }

    public void setPracticedCropCyclePhaseId(String practicedCropCyclePhaseId) {
        this.practicedCropCyclePhaseId = practicedCropCyclePhaseId;
    }

    public String getPracticedCropCycleConnectionId() {
        return practicedCropCycleConnectionId;
    }

    public void setPracticedCropCycleConnectionId(String practicedCropCycleConnectionId) {
        this.practicedCropCycleConnectionId = practicedCropCycleConnectionId;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }
}

==> agrosyst-cli-1.4.7-sources.jar: fr/inra/agrosyst/services/pz0import/practicedSystem/practicedIntervention/PracticedInterventionImportDto.java <==
package fr.inra.agrosyst.services.pz0import.practicedSystem.practicedIntervention;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: PracticedInterventionImportDto.java 4775 2015-02-10 15:13:34Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.7/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/practicedSystem/practicedIntervention/PracticedInterventionImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.services.practiced.PracticedInterventionDto;

/**
 * Created by davidcosse on 05/02/15.
 */
public class PracticedInterventionImportDto extends PracticedInterventionDto {

    protected String id;

    protected String practicedCropCyclePhaseId;

    protected String practicedCropCycleConnectionId;

    protected String typeName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPracticedCropCyclePhaseId() {
        return practicedCropCyclePhaseId;
    }

    public void setPracticedCropCyclePhaseId(String practicedCropCyclePhaseId) {
        this.practicedCropCyclePhaseId = practicedCropCyclePhaseId;
    }

    public String getPracticedCropCycleConnectionId() {
        return practicedCropCycleConnectionId;
    }

    public void setPracticedCropCycleConnectionId(String practicedCropCycleConnectionId) {
        this.practicedCropCycleConnectionId = practicedCropCycleConnectionId;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }
}
